@@ -53,7 +53,7 @@ class Column(System.Field):
         :param table: name of the table of the model
         :param ftype: type of the AnyBlok Field
         """
-        Model = cls.registry.get(model)
+        Model = cls.anyblok.get(model)
         if hasattr(Model, anyblok_column_prefix + cname):
             c = getattr(Model, anyblok_column_prefix + cname)
         else:
@@ -86,7 +86,7 @@ class Column(System.Field):
         :param meta_column: instance of the SqlAlchemy column
         :param ftype: type of the AnyBlok Field
         """
-        Model = cls.registry.get(column.model)
+        Model = cls.anyblok.get(column.model)
         if hasattr(Model, anyblok_column_prefix + column.name):
             c = getattr(Model, anyblok_column_prefix + column.name)
         else:
