@@ -4,6 +4,7 @@
 #    Copyright (C) 2014 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
 #    Copyright (C) 2017 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
 #    Copyright (C) 2018 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
+#    Copyright (C) 2019 Jean-Sebastien SUZANNE <js.suzanne@gmail.com>
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
@@ -15,16 +16,28 @@ import sys
 import os
 import json
 import yaml
+import urllib
 from appdirs import AppDirs
 from os.path import join, isfile
 from sqlalchemy.engine.url import URL, make_url
 from logging import (getLogger, config, NOTSET, DEBUG, INFO, WARNING, ERROR,
                      CRITICAL, basicConfig, Logger)
+
 logger = getLogger(__name__)
 
 
+def parse_qs(entry):
+    res = urllib.parse.parse_qs(entry)
+    for k, v in res.items():
+        if len(v) == 1:
+            res[k] = v[0]
+
+    return res
+
+
 def get_db_name():
-    """ Return an sqlalchemy name of the database from configuration
+    """Return an sqlalchemy name of the database from configuration
+
     db_name or db_url
 
     :rtype: name of the database
@@ -41,14 +54,13 @@ def get_db_name():
         if url.database:
             return url.database
 
-    raise ConfigurationException("No database's name defined")
+    raise ConfigurationException("No database name defined")
 
 
 def get_url(db_name=None):
-    """ Return an sqlalchemy URL for database
+    """Return an sqlalchemy URL for database
 
-    Get the options of the database, the only option which can be
-    overloaded is the name of the database::
+    Return database options, only the database name db_name can be overloaded::
 
         url = get_url(db_name='Mydb')
 
@@ -71,7 +83,7 @@ def get_url(db_name=None):
             get_url(db_name='Mydb')
             ==> 'postgresql://jssuzanne:secret@/Mydb'
 
-    :param db_name: Name of the database
+    :param db_name: database name
     :rtype: SqlAlchemy URL
     :exception: ConfigurationException
     """
@@ -82,6 +94,7 @@ def get_url(db_name=None):
     host = Configuration.get('db_host', None)
     port = Configuration.get('db_port', None)
     database = Configuration.get('db_name', None)
+    query = Configuration.get('db_query', {})
 
     if db_name is not None:
         database = db_name
@@ -98,20 +111,20 @@ def get_url(db_name=None):
         return url
 
     if drivername is None:
-        raise ConfigurationException('No Drivername defined')
+        raise ConfigurationException('No driver name defined')
 
     return URL(drivername, username=username, password=password, host=host,
-               port=port, database=database)
+               port=port, database=database, query=query)
 
 
 class ConfigurationException(LookupError):
-    """ Simple Exception for Configuration"""
+    """Simple Exception for Configuration"""
 
 
 def is_none(type, value):
-    """Check if the value is a *NoneValue* in function of the type
+    """Check if the value is a *NoneValue* depending on the type
 
-    :param type: type of value
+    :param type_: type of value
     :param value: value to check
     :rtype: *bool*, True if it is a *NoneValue*
     """
@@ -146,8 +159,21 @@ def cast_value(cast, value):
 
 
 def nargs_type(key, nargs, cast):
+    """Return nargs type
+
+    :param key:
+    :param nargs:
+    :param cast: final type of data wanted
+    :return:
+    """
 
     def wrap(val):
+        """Return list of casted values
+
+        :param val:
+        :return:
+        :exception ConfigurationException
+        """
         if isinstance(val, str):
             sep = ' '
             if '\n' in val:
@@ -158,7 +184,7 @@ def nargs_type(key, nargs, cast):
 
         if not isinstance(val, list):
             raise ConfigurationException("Waiting list not %r for %r "
-                                         "get : %r" % (type(val), key, val))
+                                         "get: %r" % (type(val), key, val))
 
         limit = len(val)
         if nargs not in ('?', '+', '*', REMAINDER):
@@ -172,7 +198,12 @@ def nargs_type(key, nargs, cast):
 class AnyBlokActionsContainer:
 
     def add_argument(self, *args, **kwargs):
-        """Overload the method to add the entry in the configuration dict"""
+        """Overload the method to add the entry in the configuration dict
+
+        :param args:
+        :param kwargs:
+        :return:
+        """
         default = kwargs.pop('default', None)
         nargs = kwargs.get('nargs', None)
         type = kwargs.get('type')
@@ -194,15 +225,24 @@ class AnyBlokActionsContainer:
         return arg
 
     def set_defaults(self, **kwargs):
-        """Overload the method to update the entry in the configuration dict"""
+        """Overload the method to update the entry in the configuration dict
+
+        :param kwargs:
+        """
         super(AnyBlokActionsContainer, self).set_defaults(**kwargs)
         for dest, default in kwargs.items():
             if not Configuration.has(dest):
-                raise KeyError('Unexisting option %s' % dest)
+                raise KeyError('Option %s does not exist' % dest)
 
             Configuration.set(dest, default)
 
     def add_argument_group(self, *args, **kwargs):
+        """Add argument group
+
+        :param args:
+        :param kwargs:
+        :return:
+        """
         group = AnyBlokArgumentGroup(self, *args, **kwargs)
         self._action_groups.append(group)
         return group
@@ -250,30 +290,38 @@ class ConfigOption:
         self.set(value)
 
     def get(self):
+        """Get configuration option value
+
+        :return:
+        """
         return self.value
 
     def set(self, value):
+        """Set configuration option value
+
+        :param value:
+        """
         self.value = cast_value(self.type, value)
 
 
 def getParser(**kwargs):
-    """ Return a parser
+    """Return a parser
 
-    :param description: label of the configuration help
+    :param description: configuration help description
     :rtype: ``ArgumentParser`` instance
     """
     return AnyBlokArgumentParser(**kwargs)
 
 
 class Configuration:
-    """ ``Configuration`` is used to define the options of the real argparse
+    """``Configuration`` is used to define the options of the real argparse
     and its default values. Each application or blok can declare needed
     options here.
 
     This class stores three attributes:
 
     * groups: lists of options indexed
-    * labels: if a group has got a label then all the options in group are
+    * labels: if a group has a label then all the options in group are
       gathered in a parser group
     * configuration: result of the ``Configuration`` after loading
 
@@ -302,7 +350,7 @@ class Configuration:
 
         :param application: the name of the application
         :param new_groups: list of the configuration groups
-        :param add_default_group: if True the default groups will be add
+        :param add_default_group: if True the default groups will be added
         :params kwargs: other properties to change
         """
         if application not in cls.applications:
@@ -326,14 +374,15 @@ class Configuration:
     @classmethod
     def add(cls, group, label=None, function_=None,
             must_be_loaded_by_unittest=False):
-        """ Add a function in a group.
+        """Add a function in a group.
 
-        The function must have two arguments:
+        The ``function_`` must have two arguments:
 
         * ``parser``: the parser instance of argparse
         * ``default``: A dict with the default value
 
-        This function is called to know what the options of this must do.
+        This ``function_`` defines what the option given in first argument
+        to ``add`` method must do.
         You can declare this group:
 
         * either by calling the ``add`` method as a function::
@@ -360,8 +409,8 @@ class Configuration:
         :param label: If the group has a label then all the functions in the
             group are put in group parser
         :param function_: function to add
-        :param must_be_loaded_by_unittest: unittest call this function to init
-            configuration of AnyBlok for run unittest"
+        :param must_be_loaded_by_unittest: unittest calls this function to init
+            configuration of AnyBlok to run unittest"
         """
         if group not in cls.groups:
             cls.groups[group] = []
@@ -387,13 +436,13 @@ class Configuration:
 
     @classmethod
     def has(cls, option):
-        """ Check if the option exist in the configuration dict
+        """Check if an option exists in the configuration dict
 
         Return True if the option is in the configuration dict and the
-        value is not None. A None value is diferent that a ConfigOption with
+        value is not None. A None value is different that a ConfigOption with
         None value
 
-        :param opt: option key to check
+        :param option: option key to check
         :rtype: boolean True is exist
         """
         if option in cls.configuration and cls.configuration[option]:
@@ -403,9 +452,9 @@ class Configuration:
 
     @classmethod
     def get(cls, opt, default=None):
-        """ Get a value from the configuration dict after loading
+        """Get a value from the configuration dict after loading the application
 
-        After the loading of the application, all the options are saved in the
+        When the application is loaded, all the options are saved in the
         Configuration. And all the applications have free access to
         these options::
 
@@ -428,7 +477,7 @@ class Configuration:
 
     @classmethod
     def set(cls, opt, value):
-        """ Set a value to the configuration dict
+        """Set a value to the configuration dict
 
         :param opt: name of the option
         :param value: value to set
@@ -440,18 +489,25 @@ class Configuration:
             else:
                 cls.add_argument(opt, value, type(value))
         except Exception as e:
-            logger.exception("Error durring set the value %r on the option "
+            logger.exception("Error while setting the value %r to the option "
                              "%r" % (value, opt))
             raise e
 
     @classmethod
     def update(cls, *args, **kwargs):
+        """Update option values
+
+        :param args:
+        :param kwargs:
+        :exception ConigurationException
+        """
         if args:
             if len(args) > 1:
-                raise ConfigurationException("Waiting only one dict")
+                raise ConfigurationException("Too many args. "
+                                             "Only one expected")
 
             if not isinstance(args[0], dict):
-                raise ConfigurationException("Waiting a dict")
+                raise ConfigurationException("Wrong args type. Dict expected")
 
             for k, v in args[0].items():
                 cls.set(k, v)
@@ -461,14 +517,20 @@ class Configuration:
 
     @classmethod
     def add_argument(cls, key, value, type=str):
+        """Add a configuration option
+
+        :param key:
+        :param value:
+        :param type:
+        """
         cls.configuration[key] = ConfigOption(value, type)
 
     @classmethod
     def remove_label(cls, group):
-        """ Remove an existing label
+        """Remove an existing label
 
-        The goal of this function is to remove an existing label of a specific
-        group::
+        The purpose of this function is to remove an existing label
+        from a specific group::
 
             @Configuration.add('create-db', label="Name of the group")
             def bar(parser, defaul):
@@ -483,7 +545,7 @@ class Configuration:
 
     @classmethod
     def remove(cls, group, function_):
-        """ Remove an existing function
+        """Remove an existing function
 
         If your application inherits some unwanted options from a specific
         function, you can unlink this function::
@@ -504,25 +566,36 @@ class Configuration:
     @classmethod
     @log(logger)
     def load_config_for_test(cls):
-        """Load the argparse configuration need for the unittest"""
+        """Load the argparse configuration needed for the unittest"""
         if not cls.configuration:
             parser = getParser()
             for group in cls.groups.keys():
                 for fnct in cls.groups[group]:
                     if (
-                        fnct.must_be_loaded_by_unittest or
-                        group in ('plugins',)
+                            fnct.must_be_loaded_by_unittest or
+                            group in ('plugins',)
                     ):
                         fnct(parser)
 
+            ad = AppDirs('AnyBlok')
+            # load the global configuration file
+            cls.parse_configfile(
+                join(ad.site_config_dir, 'conf.cfg'), False)
+            # load the user configuration file
+            cls.parse_configfile(
+                join(ad.user_config_dir, 'conf.cfg'), False)
+            configfile = cls.get('configfile')
+            if configfile:
+                cls.parse_configfile(configfile, True)
+
     @classmethod
     @log(logger, level='debug')
     def load(cls, application, useseparator=False, **kwargs):
-        """ Load the argparse definition and parse them
+        """Load the argparse definition and parse them
 
         :param application: name of the application
         :param useseparator: boolean(default False)
-        :param \**kwargs: ArgumentParser named arguments
+        :param **kwargs: ArgumentParser named arguments
         """
 
         sep = len(sys.argv)
@@ -554,15 +627,14 @@ class Configuration:
         cls._load(parser, configuration_groups)
         args = parser.parse_args(our_argv)
         if sep is not None:
-            del sys.argv[1:sep+1]
+            del sys.argv[1:sep + 1]
 
         cls.parse_options(args)
 
     @classmethod
     def _load(cls, parser, configuration_groups):
-        """ Load the argparse definition and parse them
+        """Load the argparse definition and parse them
 
-        :param description: description of configuration
         :param configuration_groups: list configuration groupe to load
         :param useseparator: boolean(default False)
         """
@@ -584,6 +656,8 @@ class Configuration:
 
     @classmethod
     def initialize_logging(cls):
+        """Initialize logger and configure
+        """
         level = {
             'NOTSET': NOTSET,
             'DEBUG': DEBUG,
@@ -623,6 +697,12 @@ class Configuration:
 
     @classmethod
     def parse_configfile(cls, configfile, required):
+        """Parse the configuration file
+
+        :param configfile:
+        :param required:
+        :return:
+        """
         cur_cwd = os.getcwd()
         configfile = os.path.abspath(configfile)
         print('Loading config file %r' % configfile)
@@ -661,6 +741,10 @@ class Configuration:
 
     @classmethod
     def parse_options(cls, arguments):
+        """Parse options
+
+        :param arguments:
+        """
         if arguments._get_args():
             raise ConfigurationException(
                 'Positional arguments are forbidden')
@@ -687,6 +771,10 @@ class Configuration:
 @Configuration.add('plugins', label='Plugins',
                    must_be_loaded_by_unittest=True)
 def add_plugins(group):
+    """Add arguments to 'plugins' configuration group
+
+    :param group:
+    """
     group.add_argument('--registry-cls', dest='Registry', type=AnyBlokPlugin,
                        default='anyblok.registry:Registry',
                        help="Registry class to use")
@@ -700,9 +788,14 @@ def add_plugins(group):
                        help="get_url function to use")
 
 
-@Configuration.add('config')
+@Configuration.add('config', must_be_loaded_by_unittest=True)
 def add_configuration_file(parser):
+    """Add arguments to 'config' configuration group
+
+    :param parser:
+    """
     parser.add_argument('-c', dest='configfile',
+                        default=os.environ.get('ANYBLOK_CONFIG_FILE'),
                         help="Relative path of the config file")
     parser.add_argument('--without-auto-migration', dest='withoutautomigration',
                         action='store_true')
@@ -720,6 +813,10 @@ def add_configuration_file(parser):
 @Configuration.add('database', label="Database",
                    must_be_loaded_by_unittest=True)
 def add_database(group):
+    """Add arguments to 'database' configuration group
+
+    :param group:
+    """
     group.add_argument('--db-name',
                        default=os.environ.get('ANYBLOK_DATABASE_NAME'),
                        help="Name of the database")
@@ -743,6 +840,9 @@ def add_database(group):
     group.add_argument('--db-port', type=int,
                        default=os.environ.get('ANYBLOK_DATABASE_PORT'),
                        help="The port number")
+    group.add_argument('--db-query', type=parse_qs,
+                       default=os.environ.get('ANYBLOK_DATABASE_QUERY'),
+                       help="Query string to add parameter to the connection")
     group.add_argument('--db-echo', action="store_true",
                        default=(os.environ.get(
                            'ANYBLOK_DATABASE_ECHO') or False))
@@ -757,14 +857,32 @@ def add_database(group):
 
 @Configuration.add('create_db', must_be_loaded_by_unittest=True)
 def add_create_database(group):
+    """Add arguments to 'create_db' configuration group
+
+    :param group:
+    """
     group.add_argument(
         '--db-template-name',
         default=os.environ.get('ANYBLOK_DATABASE_TEMPLATE_NAME'),
         help="Name of the template")
+    group.add_argument(
+        '--with-demo',
+        default=os.environ.get('ANYBLOK_WITH_DEMO', False),
+        action='store_true',
+        help="Call **update_demo** method define on bloks to import demo data "
+             "while installing the project. If this option is used at database "
+             "creation that information will be kept in the database then "
+             "**update_demo** method will be called while updating bloks as "
+             "well.",
+    )
 
 
 @Configuration.add('install-bloks')
 def add_install_bloks(parser):
+    """Add arguments to 'install-bloks' configuration group
+
+    :param parser:
+    """
     parser.add_argument('--install-bloks', nargs="+", help="blok to install")
     parser.add_argument('--install-all-bloks', action='store_true')
     parser.add_argument('--test-blok-at-install', action='store_true')
@@ -772,18 +890,30 @@ def add_install_bloks(parser):
 
 @Configuration.add('uninstall-bloks')
 def add_uninstall_bloks(parser):
+    """Add arguments to 'uninstall-bloks' configuration group
+
+    :param parser:
+    """
     parser.add_argument('--uninstall-bloks', nargs="+",
                         help="bloks to uninstall")
 
 
 @Configuration.add('install-or-update-bloks')
 def add_install_or_update_bloks(parser):
+    """Add arguments to 'install-or-update-bloks' configuration group
+
+    :param parser:
+    """
     parser.add_argument('--install-or-update-bloks', nargs="+",
                         help="bloks to install or update")
 
 
 @Configuration.add('update-bloks', label='Update database')
 def add_update_bloks(parser):
+    """Add arguments to 'update-bloks' configuration group
+
+    :param parser:
+    """
     parser.add_argument('--update-bloks', nargs="+", help="bloks to update")
     parser.add_argument('--update-all-bloks', action='store_true')
     parser.add_argument('--reinit-all', action='store_true')
@@ -795,12 +925,20 @@ def add_update_bloks(parser):
 
 @Configuration.add('interpreter')
 def add_interpreter(parser):
+    """Add arguments to 'interpreter' configuration group
+
+    :param parser:
+    """
     parser.add_argument('--script', dest='python_script',
                         help="Python script to execute")
 
 
 @Configuration.add('schema', label="Schema options")
 def add_schema(group):
+    """Add arguments to 'schema' configuration group
+
+    :param group:
+    """
     try:
         from graphviz.files import FORMATS
     except ImportError:
@@ -812,6 +950,10 @@ def add_schema(group):
 
 @Configuration.add('doc', label="Doc options")
 def add_doc(group):
+    """Add arguments to 'doc' configuration group
+
+    :param group:
+    """
     group.add_argument('--doc-format',
                        default='RST', choices=('RST', 'UML', 'SQL'))
     group.add_argument('--doc-output',
@@ -822,16 +964,12 @@ def add_doc(group):
                        help='No detail these models')
 
 
-@Configuration.add('unittest', label="Unittest")
-def add_unittest(group):
-    group.add_argument('--selected-bloks', nargs='+',
-                       help="Name of the bloks to test")
-    group.add_argument('--unwanted-bloks', nargs='+',
-                       help="Name of the bloks to no test")
-
-
 @Configuration.add('logging', label="Logging")
 def add_logging(group):
+    """Add arguments to 'logging' configuration group
+
+    :param group:
+    """
     group.add_argument('--logging-level', dest='logging_level',
                        choices=['NOTSET', 'DEBUG', 'INFO', 'WARNING',
                                 'ERROR', 'CRITICAL'])
@@ -852,5 +990,9 @@ def add_logging(group):
 
 @Configuration.add('preload', label="Preload")
 def define_preload_option(group):
+    """Add arguments to 'preload' configuration group
+
+    :param group:
+    """
     group.add_argument('--databases', dest='db_names', nargs="+",
                        help='List of the database allow to be load')
