@@ -223,6 +223,23 @@ class TestModel2:
         self.registry = init_registry(*args, **kwargs)
         return self.registry
 
+    def test_anyblok_attribute(self):
+        registry = self.init_registry(simple_model)
+        self.check_registry(registry.Test)
+        assert registry.System.anyblok is registry
+        assert registry.System.Model.anyblok is registry
+        t2 = registry.Test.query().first()
+        registry.System.Model.anyblok.refresh(t2)
+
+    def test_deprecated_registry_attribute(self):
+        registry = self.init_registry(simple_model)
+        self.check_registry(registry.Test)
+        assert registry.System.registry  # NoSQL Base must also have registry
+        assert registry.System.Model.registry
+        assert registry.System.Model.registry is not registry
+        t2 = registry.Test.query().first()
+        registry.System.Model.registry.refresh(t2)
+
     def test_model_is_assembled(self):
         with LogCapture('anyblok.registry', level=DEBUG) as logs:
             self.init_registry(None)
